﻿''' <summary>
''' Sample program demonstrating the Web Service submission of a criminal complaint.
''' </summary>
''' <remarks></remarks>
Public Class SubmitCriminalComplaint
    Const USER_NAME As String = "Your Account"
    Const PASSWORD As String = "Your Password"


    Shared Sub Main()
        'Submit the complaint
        ' Submit(True)

        'Pull the response messages only if submitted with pull responses option = true
        PullResponses()
    End Sub


    Shared Sub Submit(ByVal ablnPullResponses As Boolean)
        '
        'Create an object reference to the service use the custom binding defined in the app.config file to 
        'make use of ws-addressing 2004.
        'Edit the endpoint in the app config file to change the address that is called.
        '
        'Connect to the service
        '
        Dim objSVC As New CriminalComplaintService.CriminalComplaintService_3_3Client("CriminalComplaintService_3_3_cu")
        '
        'Setup the security token
        '
        objSVC.ClientCredentials.UserName.UserName = USER_NAME
        objSVC.ClientCredentials.UserName.Password = PASSWORD

        Dim objHoldResponse As CriminalComplaintService.HoldResponse = Nothing
        Dim objResponseTo As CriminalComplaintService.ResponseTo = Nothing

        If ablnPullResponses Then
            objHoldResponse = New CriminalComplaintService.HoldResponse
            objHoldResponse.RetrievalCode = "MyResponses"
        Else
            objResponseTo = New CriminalComplaintService.ResponseTo
            objResponseTo.Address = "https://myreceiverservice.ext"
        End If


        '
        'Create the request message
        '
        Dim objRequest As New CriminalComplaintService.CriminalComplaintDocument

        objRequest.messageProducedDateTime = Now()
        objRequest.EFileID = New CriminalComplaintService.EFileIDType
        objRequest.EFileID.ID = "123456"
        objRequest.schemaVersion = "3:3"
        objRequest.SubmittingAgencyORI = New CriminalComplaintService.SubmittingAgencyORIType
        objRequest.SubmittingAgencyORI.ID = "MN002015J"

        'filing
        objRequest.Filing = New CriminalComplaintService.CriminalComplaintDocumentFiling
        objRequest.Filing.CourtJurisdictionORI = New CriminalComplaintService.CourtJurisdictionORIType
        objRequest.Filing.CourtJurisdictionORI.ID = "MN003015J"
        objRequest.Filing.ComplaintTypeText = New CriminalComplaintService.CriminalComplaintDocumentFilingComplaintTypeText
        objRequest.Filing.ComplaintTypeText = CriminalComplaintService.CriminalComplaintDocumentFilingComplaintTypeText.ComplaintOrderForDetention
        objRequest.Filing.ProsecutingAgencyORI = New CriminalComplaintService.ProsecutingAgencyORIType
        objRequest.Filing.ProsecutingAgencyORI.ID = "MN003013A"

        'defendant
        objRequest.Defendant = New CriminalComplaintService.DefendantType
        objRequest.Defendant.PartyName = New CriminalComplaintService.PartyNameType
        Dim objPersonName As New CriminalComplaintService.PersonNameType
        objPersonName.PersonGivenName = "Spongebob"
        objPersonName.PersonSurName = "Squarepants"
        objRequest.Defendant.PartyName.Item = objPersonName
        ReDim objRequest.Defendant.PersonBirthDate(0)
        objRequest.Defendant.PersonBirthDate(0) = #9/9/1985#

        'charge
        ReDim Preserve objRequest.Charge(0)
        Dim objCharge As New CriminalComplaintService.ComplaintChargeType
        objRequest.Charge(0) = objCharge
        objCharge.ChargeSequenceID = New CriminalComplaintService.ChargeSequenceIDType
        objCharge.ChargeSequenceID.ID = "1"
        objCharge.OffenseID = New CriminalComplaintService.OffenseIDType
        objCharge.OffenseID.ID = "2687"
        objCharge.SeverityLevelText = New CriminalComplaintService.OffenseSeverityLevelTypeCodeTextType
        objCharge.SeverityLevelText.Value = "Misdemeanor"
        objCharge.OffenseDate = DateAdd(DateInterval.Day, -1, Now)
        objCharge.OffenseTime = CDate("07:30")
        objCharge.CommunityOfOffenseText = New CriminalComplaintService.CommunityOfOffenseCodeTextType
        objCharge.CommunityOfOffenseText.Value = "Audubon"
        objCharge.Report = New CriminalComplaintService.ComplaintChargeTypeReport
        objCharge.Report.ReportingAgencyControlNumber = New CriminalComplaintService.ControlNumberInType
        objCharge.Report.ReportingAgencyControlNumber.ID = "12345678"
        objCharge.Report.ReportingAgencyORI = New CriminalComplaintService.ReportingAgencyORIType
        objCharge.Report.ReportingAgencyORI.ID = "MN0030000"



        '
        'Call the service
        '
        If ablnPullResponses Then
            If Not objSVC.SubmitCriminalComplaintDocument(objHoldResponse, Nothing, objRequest) Then
                MsgBox("Error during submission (pull)")
            Else
                MsgBox("Message submitted (pull)")
            End If
        Else
            If Not objSVC.SubmitCriminalComplaintDocument(Nothing, objResponseTo, objRequest) Then
                MsgBox("Error during submission (push)")
            Else
                MsgBox("Message submitted (push)")
            End If
        End If
        '
        'Now do something with the reply
        ''


    End Sub





    Shared Sub PullResponses()
        '
        'Pull all available response messages with the retrieval code "MyComplaints".   This only can be used if submissions used the HoldResponse header.
        '
        Dim intRemainingResponses As Integer = 1
        Dim intPulledCount As Integer
        Dim objEFileID As CriminalComplaintService.EFileIDType = Nothing
        Dim objSubAgency As CriminalComplaintService.SubmittingAgencyORIType = Nothing

        '
        'Connect to the service
        '
        Dim objSVC As New CriminalComplaintService.CriminalComplaintService_3_3Client("CriminalComplaintService_3_3_cu")
        '
        'Setup the security token
        '
        objSVC.ClientCredentials.UserName.UserName = USER_NAME
        objSVC.ClientCredentials.UserName.Password = PASSWORD

        Dim objPullReply As CriminalComplaintService.PullReplyXml = Nothing

        Dim objResopnseXmlElement As System.Xml.XmlElement

        Dim objPullRequest As New CriminalComplaintService.PullRequestXml
        objPullRequest.RetrievalCode = "MyResponses"



        While intRemainingResponses > 0

            objEFileID = objSVC.PullHeldCriminalComplaintDocumentResponse(objPullRequest, objSubAgency, objPullReply)

            intRemainingResponses = objPullReply.RemainingMessagesCount
            intPulledCount = objPullReply.MessagePulledCount
            If intPulledCount >= 8 Then
                'for some reason the same message has been pulled 8 or more times.   Someone should look at this (8 chosen as an example)
                Err.Raise(-1, "Message pulled 8 tiems")
            End If


            'Check if a message was returned.   If it was then process it.
            If Not objPullReply.MessageXml Is Nothing Then
                'Process the response.   Item could be a Fault or an AttorneyAssignmenttResponse


                'Do somthing with the resopnse xml
                objResopnseXmlElement = objPullReply.MessageXml



                'After processing the response release it so the next pull will get the next un-pulled message
                ReleaseResponse(objPullReply)

            End If

        End While



    End Sub

    Shared Sub ReleaseResponse(ByVal aobjPullReply As CriminalComplaintService.PullReplyXml)
        '
        'Connect to the service
        '
        Dim objSVC As New CriminalComplaintService.CriminalComplaintService_3_3Client("CriminalComplaintService_3_3_cu")
        '
        'Setup the security token
        '
        objSVC.ClientCredentials.UserName.UserName = USER_NAME
        objSVC.ClientCredentials.UserName.Password = PASSWORD

        'Set up the messages
        Dim objReleaseReply As CriminalComplaintService.ReleaseReplyXml

        Dim objReleaseRequest As New CriminalComplaintService.ReleaseRequestXml

        objReleaseRequest.MessageID = aobjPullReply.MessageID
        objReleaseRequest.messageProducedDateTime = Now
        objReleaseRequest.messageProducedDateTimeSpecified = True


        'Call the service
        objReleaseReply = objSVC.ReleaseHeldCriminalComplaintDocumentResponse(objReleaseRequest)


    End Sub



End Class
